'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

exports.default = jssNested;
var warn = console.warn.bind(console); // eslint-disable-line no-console
var parentRegExp = /&/g;
var refRegExp = /\$(\w+)/g;

/**
 * Get a function to be used for $ref replacement.
 */
function getReplaceRef(sheet) {
  return function (match, name) {
    var rule = sheet.getRule(name);
    if (rule) return rule.selector;
    warn('JSS: could not find the referenced rule ' + name + '.');
    return name;
  };
}

/**
 * Convert nested rules to separate, remove them from original styles.
 *
 * @param {Rule} rule
 * @api public
 */
function jssNested() {
  return function (rule) {
    if (rule.type !== 'regular') return;
    var _rule$options = rule.options;
    var sheet = _rule$options.sheet;
    var jss = _rule$options.jss;
    var parent = _rule$options.parent;

    var container = sheet || jss;
    var options = void 0;
    var replaceRef = void 0;

    if (parent && parent.type === 'conditional') {
      container = parent;
    }

    for (var prop in rule.style) {
      if (prop[0] === '&') {
        if (!options) options = _extends({}, rule.options, { named: false });
        // Lazily create the ref replacer function just once for all nested rules within
        // the sheet.
        if (!replaceRef) replaceRef = getReplaceRef(container);

        var name = prop
        // Replace all & by the parent selector.
        .replace(parentRegExp, rule.selector)
        // Replace all $ref.
        .replace(refRegExp, replaceRef);

        // Conditional rule has no `.addRule()`.
        // Use `.addRule()` in regular rules to render a nested rule
        // when a sheet is attached.
        var method = container.addRule ? 'addRule' : 'createRule';
        container[method](name, rule.style[prop], options);
        delete rule.style[prop];
      }
    }
  };
}